@@ -25,13 +25,11 @@ import (
 	"bytes"
 	"fmt"
 	"io"
-	"io/ioutil"
 	"os"
 	"strings"
 
 	"github.com/gonvenience/bunt"
 	"github.com/gonvenience/neat"
-	"github.com/gonvenience/wrap"
 	"github.com/gonvenience/ytbx"
 	"github.com/spf13/cobra"
 	yamlv3 "gopkg.in/yaml.v3"
@@ -48,6 +46,9 @@ type reportConfig struct {
 	exitWithCode              bool
 	omitHeader                bool
 	useGoPatchPaths           bool
+	minorChangeThreshold      float64
+	multilineContextLines     int
+	additionalIdentifiers     []string
 	filters                   []string
 	excludes                  []string
 	filterRegexps             []string
@@ -63,6 +64,9 @@ var defaults = reportConfig{
 	exitWithCode:              false,
 	omitHeader:                false,
 	useGoPatchPaths:           false,
+	minorChangeThreshold:      0.1,
+	multilineContextLines:     4,
+	additionalIdentifiers:     nil,
 	filters:                   nil,
 	excludes:                  nil,
 	filterRegexps:             nil,
@@ -75,13 +79,14 @@ func applyReportOptionsFlags(cmd *cobra.Command) {
 	// Compare options
 	cmd.Flags().BoolVarP(&reportOptions.ignoreOrderChanges, "ignore-order-changes", "i", defaults.ignoreOrderChanges, "ignore order changes in lists")
 	cmd.Flags().BoolVarP(&reportOptions.kubernetesEntityDetection, "detect-kubernetes", "", defaults.kubernetesEntityDetection, "detect kubernetes entities")
+	cmd.Flags().StringArrayVar(&reportOptions.additionalIdentifiers, "additional-identifier", defaults.additionalIdentifiers, "use additional identifier candidates in named entry lists")
 	cmd.Flags().StringSliceVar(&reportOptions.filters, "filter", defaults.filters, "filter reports to a subset of differences based on supplied arguments")
 	cmd.Flags().StringSliceVar(&reportOptions.excludes, "exclude", defaults.excludes, "exclude reports from a set of differences based on supplied arguments")
 	cmd.Flags().StringSliceVar(&reportOptions.filterRegexps, "filter-regexp", defaults.filterRegexps, "filter reports to a subset of differences based on supplied regular expressions")
 	cmd.Flags().StringSliceVar(&reportOptions.excludeRegexps, "exclude-regexp", defaults.excludeRegexps, "exclude reports from a set of differences based on supplied regular expressions")
 
 	// Main output preferences
-	cmd.Flags().StringVarP(&reportOptions.style, "output", "o", defaults.style, "specify the output style, supported styles: human, or brief")
+	cmd.Flags().StringVarP(&reportOptions.style, "output", "o", defaults.style, "specify the output style, supported styles: human, brief, github, gitlab, gitea")
 	cmd.Flags().BoolVarP(&reportOptions.omitHeader, "omit-header", "b", defaults.omitHeader, "omit the dyff summary header")
 	cmd.Flags().BoolVarP(&reportOptions.exitWithCode, "set-exit-code", "s", defaults.exitWithCode, "set program exit code, with 0 meaning no difference, 1 for differences detected, and 255 for program error")
 
@@ -116,7 +121,7 @@ func humanReadableFilename(filename string) string {
 // stored in the provided input file to the standard output
 func (w *OutputWriter) WriteToStdout(filename string) error {
 	if err := w.write(os.Stdout, filename); err != nil {
-		return wrap.Error(err, bunt.Sprint("failed to write output to _*stdout*_"))
+		return bunt.Errorf("failed to write output to _*stdout*_: %w", err)
 	}
 
 	return nil
@@ -131,13 +136,13 @@ func (w *OutputWriter) WriteInplace(filename string) error {
 	// Force plain mode to make sure there are no ANSI sequences
 	w.PlainMode = true
 	if err := w.write(bufWriter, filename); err != nil {
-		return wrap.Errorf(err, "failed to write output to %s", humanReadableFilename(filename))
+		return fmt.Errorf("failed to write output to %s: %w", humanReadableFilename(filename), err)
 	}
 
 	// Write the buffered output to the provided input file (override in place)
 	bufWriter.Flush()
-	if err := ioutil.WriteFile(filename, buf.Bytes(), 0644); err != nil {
-		return wrap.Errorf(err, "failed to overwrite %s in place", humanReadableFilename(filename))
+	if err := os.WriteFile(filename, buf.Bytes(), 0644); err != nil {
+		return fmt.Errorf("failed to overwrite %s in place: %w", humanReadableFilename(filename), err)
 	}
 
 	return nil
@@ -146,7 +151,7 @@ func (w *OutputWriter) WriteInplace(filename string) error {
 func (w *OutputWriter) write(writer io.Writer, filename string) error {
 	inputFile, err := ytbx.LoadFile(filename)
 	if err != nil {
-		return wrap.Errorf(err, "failed to load input from %s", humanReadableFilename(filename))
+		return fmt.Errorf("failed to load input from %s: %w", humanReadableFilename(filename), err)
 	}
 
 	for _, document := range inputFile.Documents {
@@ -199,12 +204,69 @@ func writeReport(cmd *cobra.Command, report dyff.Report) error {
 	switch strings.ToLower(reportOptions.style) {
 	case "human", "bosh":
 		reportWriter = &dyff.HumanReport{
-			Report:               report,
-			DoNotInspectCerts:    reportOptions.doNotInspectCerts,
-			NoTableStyle:         reportOptions.noTableStyle,
-			OmitHeader:           reportOptions.omitHeader,
-			UseGoPatchPaths:      reportOptions.useGoPatchPaths,
-			MinorChangeThreshold: 0.1,
+			Report:                report,
+			Indent:                2,
+			DoNotInspectCerts:     reportOptions.doNotInspectCerts,
+			NoTableStyle:          reportOptions.noTableStyle,
+			OmitHeader:            reportOptions.omitHeader,
+			UseGoPatchPaths:       reportOptions.useGoPatchPaths,
+			MinorChangeThreshold:  reportOptions.minorChangeThreshold,
+			MultilineContextLines: reportOptions.multilineContextLines,
+			PrefixMultiline:       false,
+		}
+
+	case "github", "linguist":
+		reportWriter = &dyff.DiffSyntaxReport{
+			PathPrefix:            "@@",
+			RootDescriptionPrefix: "#",
+			ChangeTypePrefix:      "!",
+			HumanReport: dyff.HumanReport{
+				Report:                report,
+				Indent:                0,
+				DoNotInspectCerts:     reportOptions.doNotInspectCerts,
+				NoTableStyle:          true,
+				OmitHeader:            true,
+				UseGoPatchPaths:       reportOptions.useGoPatchPaths,
+				MinorChangeThreshold:  reportOptions.minorChangeThreshold,
+				MultilineContextLines: reportOptions.multilineContextLines,
+				PrefixMultiline:       true,
+			},
+		}
+
+	case "gitlab", "rogue":
+		reportWriter = &dyff.DiffSyntaxReport{
+			PathPrefix:            "=",
+			RootDescriptionPrefix: "=",
+			ChangeTypePrefix:      "#",
+			HumanReport: dyff.HumanReport{
+				Report:                report,
+				Indent:                0,
+				DoNotInspectCerts:     reportOptions.doNotInspectCerts,
+				NoTableStyle:          true,
+				OmitHeader:            true,
+				UseGoPatchPaths:       reportOptions.useGoPatchPaths,
+				MinorChangeThreshold:  reportOptions.minorChangeThreshold,
+				MultilineContextLines: reportOptions.multilineContextLines,
+				PrefixMultiline:       true,
+			},
+		}
+
+	case "gitea", "forgejo":
+		reportWriter = &dyff.DiffSyntaxReport{
+			PathPrefix:            "@@",
+			RootDescriptionPrefix: "=",
+			ChangeTypePrefix:      "!",
+			HumanReport: dyff.HumanReport{
+				Report:                report,
+				Indent:                0,
+				DoNotInspectCerts:     reportOptions.doNotInspectCerts,
+				NoTableStyle:          true,
+				OmitHeader:            true,
+				UseGoPatchPaths:       reportOptions.useGoPatchPaths,
+				MinorChangeThreshold:  reportOptions.minorChangeThreshold,
+				MultilineContextLines: reportOptions.multilineContextLines,
+				PrefixMultiline:       true,
+			},
 		}
 
 	case "brief", "short", "summary":
@@ -213,14 +275,11 @@ func writeReport(cmd *cobra.Command, report dyff.Report) error {
 		}
 
 	default:
-		return wrap.Errorf(
-			fmt.Errorf(cmd.UsageString()),
-			"unknown output style %s", reportOptions.style,
-		)
+		return fmt.Errorf("unknown output style %s: %w", reportOptions.style, fmt.Errorf(cmd.UsageString()))
 	}
 
 	if err := reportWriter.WriteReport(os.Stdout); err != nil {
-		return wrap.Errorf(err, "failed to print report")
+		return fmt.Errorf("failed to print report: %w", err)
 	}
 
 	// If configured, make sure `dyff` exists with an exit status
